#
# Configuration file for using the Bonobo library in GNOME applications
#
GAL_LIBDIR="-L/usr/X11R6/lib"
GAL_LIBS="-lgal -L/usr/X11R6/lib -L/usr/local/lib -lgnomeprint -lxpg4 -lglade-gnome -lglade -lxml -lXpm -lgnomeui -lart_lgpl -lgdk_imlib -ltiff -ljpeg -lungif -lpng -lz -lSM -lICE -lgnome -lgnomesupport -lesd -laudiofile -lgdk_pixbuf -lgtk12 -lgdk12 -lgmodule12 -lglib12 -ldl -lintl -lXext -lX11 -lm -lgnomecanvaspixbuf  -liconv"
GAL_INCLUDEDIR="-I/usr/X11R6/include -I/usr/X11R6/include/gnome-1.0 -I/usr/X11R6/include -DNEED_GNOMESUPPORT_H -I/usr/X11R6/lib/gnome-libs/include -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include/gdk-pixbuf-1.0 -I/usr/local/include/gnome-xml -I/usr/X11R6/include/libglade-1.0 "
MODULE_VERSION="gal-0.19.2"
